couchdb.schema.ListField.Proxy

Package couchdb :: Module schema :: Class ListField :: Class Proxy |

# Class Proxy

    object --+
             |
          list --+
                 |
                ListField.Proxy

Instance Methods
new list |
__init__(self, list, field) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
__lt__(self, other) x<y |
__le__(self, other) x<=y |
__eq__(self, other) x==y |
__ne__(self, other) x!=y |
__gt__(self, other) x>y |
__ge__(self, other) x>=y |
__repr__(self) repr(x) |
__str__(self) str(x) |
__unicode__(self) |
__delitem__(self, index) del x[y] |
__getitem__(self, index) x[y] |
__setitem__(self, index, value) x[i]=y |
__delslice__(self, i, j) del x[i:j] |
__getslice__(self, i, j) x[i:j] |
__setslice__(self, i, j, seq) x[i:j]=y |
__contains__(self, value) y in x |
__iter__(self) iter(x) |
__len__(self) len(x) |
__nonzero__(self) |
append(self, *args, **kwargs) append object to end |
integer |
count(self, value) return number of occurrences of value |
extend(self, list) extend list by appending elements from the iterable |
index(self, value) L.index(value, [start, [stop]]) -> integer -- return first index of value. |
insert(self, idx, *args, **kwargs) insert object before index |
remove(self, value) remove first occurrence of value. |
item |
pop(self, *args) remove and return item at index (default last). |
Inherited from `list`: `__add__`, `__getattribute__`, `__iadd__`, `__imul__`, `__mul__`, `__new__`, `__reversed__`, `__rmul__`, `__sizeof__`, `reverse`, `sort` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Class Variables
Inherited from `list`: `__hash__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, list, field) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Returns: new list Overrides: object.__init__ (inherited documentation)

### __lt__(self, other) (Less-than operator) |
x<y Overrides: list.__lt__ (inherited documentation)

### __le__(self, other) (Less-than-or-equals operator) |
x<=y Overrides: list.__le__ (inherited documentation)

### __eq__(self, other) (Equality operator) |
x==y Overrides: list.__eq__ (inherited documentation)

### __ne__(self, other) |
x!=y Overrides: list.__ne__ (inherited documentation)

### __gt__(self, other) (Greater-than operator) |
x>y Overrides: list.__gt__ (inherited documentation)

### __ge__(self, other) (Greater-than-or-equals operator) |
x>=y Overrides: list.__ge__ (inherited documentation)

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)

### __str__(self) (Informal representation operator) |
str(x) Overrides: object.__str__ (inherited documentation)

### __delitem__(self, index) (Index deletion operator) |
del x[y] Overrides: list.__delitem__ (inherited documentation)

### __getitem__(self, index) (Indexing operator) |
x[y] Overrides: list.__getitem__ (inherited documentation)

### __setitem__(self, index, value) (Index assignment operator) |
x[i]=y Overrides: list.__setitem__ (inherited documentation)

### __delslice__(self, i, j) (Slice deletion operator) |
del x[i:j] Use of negative indices is not supported. Overrides: list.__delslice__ (inherited documentation)

### __getslice__(self, i, j) (Slicling operator) |
x[i:j] Use of negative indices is not supported. Overrides: list.__getslice__ (inherited documentation)

### __setslice__(self, i, j, seq) (Slice assignment operator) |
x[i:j]=y Use of negative indices is not supported. Overrides: list.__setslice__ (inherited documentation)

### __contains__(self, value) (In operator) |
y in x Overrides: list.__contains__ (inherited documentation)

### __iter__(self) |
iter(x) Overrides: list.__iter__ (inherited documentation)

### __len__(self) (Length operator) |
len(x) Overrides: list.__len__ (inherited documentation)

### append(self, *args, **kwargs) |
append object to end Overrides: list.append (inherited documentation)

### count(self, value) |
return number of occurrences of value Returns: integer Overrides: list.count (inherited documentation)

### extend(self, list) |
extend list by appending elements from the iterable Overrides: list.extend (inherited documentation)

### index(self, value) |
L.index(value, [start, [stop]]) -> integer -- return first index of value. Raises ValueError if the value is not present. Overrides: list.index (inherited documentation)

### insert(self, idx, *args, **kwargs) |
insert object before index Overrides: list.insert (inherited documentation)

### remove(self, value) |
remove first occurrence of value. Raises ValueError if the value is not present. Overrides: list.remove (inherited documentation)

### pop(self, *args) |
remove and return item at index (default last). Raises IndexError if list is empty or index is out of range. Returns: item Overrides: list.pop (inherited documentation)